@@ -18,18 +18,12 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkidrsservice.endpoint import endpoint_data
 
 class CreateLiveRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'idrsservice', '2020-06-30', 'CreateLive','idrsservice')
 		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 
 	def get_ClientToken(self):
 		return self.get_query_params().get('ClientToken')
@@ -43,12 +37,6 @@ class CreateLiveRequest(RpcRequest):
 	def set_UserId(self,UserId):
 		self.add_query_param('UserId',UserId)
 
-	def get_RtcCode(self):
-		return self.get_query_params().get('RtcCode')
-
-	def set_RtcCode(self,RtcCode):
-		self.add_query_param('RtcCode',RtcCode)
-
 	def get_AppId(self):
 		return self.get_query_params().get('AppId')
 
