@@ -18,18 +18,12 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkidrsservice.endpoint import endpoint_data
 
 class CreateTaskGroupRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'idrsservice', '2020-06-30', 'CreateTaskGroup','idrsservice')
 		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 
 	def get_ClientToken(self):
 		return self.get_query_params().get('ClientToken')
@@ -44,7 +38,7 @@ class CreateTaskGroupRequest(RpcRequest):
 		self.add_query_param('ExpireAt',ExpireAt)
 
 	def get_Days(self):
-		return self.get_query_params().get('Day')
+		return self.get_query_params().get('Days')
 
 	def set_Days(self, Days):
 		for depth1 in range(len(Days)):
@@ -70,7 +64,7 @@ class CreateTaskGroupRequest(RpcRequest):
 		self.add_query_param('GroupName',GroupName)
 
 	def get_VideoUrls(self):
-		return self.get_query_params().get('VideoUrl')
+		return self.get_query_params().get('VideoUrls')
 
 	def set_VideoUrls(self, VideoUrls):
 		for depth1 in range(len(VideoUrls)):
