@@ -18,21 +18,15 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkidrsservice.endpoint import endpoint_data
 
 class DeleteUserDepartmentsRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'idrsservice', '2020-06-30', 'DeleteUserDepartments','idrsservice')
 		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 
 	def get_DepartmentIds(self):
-		return self.get_query_params().get('DepartmentId')
+		return self.get_query_params().get('DepartmentIds')
 
 	def set_DepartmentIds(self, DepartmentIds):
 		for depth1 in range(len(DepartmentIds)):
@@ -40,7 +34,7 @@ class DeleteUserDepartmentsRequest(RpcRequest):
 				self.add_query_param('DepartmentId.' + str(depth1 + 1) , DepartmentIds[depth1])
 
 	def get_UserIds(self):
-		return self.get_body_params().get('UserId')
+		return self.get_body_params().get('UserIds')
 
 	def set_UserIds(self, UserIds):
 		for depth1 in range(len(UserIds)):
