@@ -18,18 +18,12 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkidrsservice.endpoint import endpoint_data
 
 class ExitLiveRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'idrsservice', '2020-06-30', 'ExitLive','idrsservice')
 		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
 
 	def get_Channel(self):
 		return self.get_query_params().get('Channel')
@@ -41,10 +35,4 @@ class ExitLiveRequest(RpcRequest):
 		return self.get_query_params().get('UserId')
 
 	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_RtcCode(self):
-		return self.get_query_params().get('RtcCode')
-
-	def set_RtcCode(self,RtcCode):
-		self.add_query_param('RtcCode',RtcCode)
\ No newline at end of file
+		self.add_query_param('UserId',UserId)
\ No newline at end of file
