@@ -18,30 +18,12 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkidrsservice.endpoint import endpoint_data
 
 class UpdateServiceConfigurationRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'idrsservice', '2020-06-30', 'UpdateServiceConfiguration','idrsservice')
 		self.set_method('POST')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
-
-	def get_LiveRecordMaxClient(self):
-		return self.get_query_params().get('LiveRecordMaxClient')
-
-	def set_LiveRecordMaxClient(self,LiveRecordMaxClient):
-		self.add_query_param('LiveRecordMaxClient',LiveRecordMaxClient)
-
-	def get_LiveRecordVideoResolution(self):
-		return self.get_query_params().get('LiveRecordVideoResolution')
-
-	def set_LiveRecordVideoResolution(self,LiveRecordVideoResolution):
-		self.add_query_param('LiveRecordVideoResolution',LiveRecordVideoResolution)
 
 	def get_TaskItemQueueSize(self):
 		return self.get_query_params().get('TaskItemQueueSize')
